package com.mobula.sample;

import android.app.Activity;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.RatingBar;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.duapps.ad.AdError;
import com.duapps.ad.DuAdDataCallBack;
import com.duapps.ad.entity.strategy.NativeAd;
import com.duapps.ad.list.AdListArrivalListener;
import com.duapps.ad.list.DuNativeAdsManager;
import com.nostra13.universalimageloader.core.ImageLoader;
import com.nostra13.universalimageloader.core.assist.FailReason;
import com.nostra13.universalimageloader.core.listener.ImageLoadingListener;

import java.util.LinkedList;
import java.util.List;

/**
 * Created by baidu on 15/9/9.
 */

/**
 * display the ads page 显示广告页
 *
 * @author mobula team
 */
public class ListAdActivity extends Activity {

    private static final String TAG = "ListAdActivity";
    /**
     * ad recommend id 广告推荐位
     */
    private static final int PID = 10032;
    /**
     * cache data size 缓存大小
     */
    private static final int CACHESZIE = 10;
    /**
     * mobula ad data mobula广告数据类
     */
    private DuNativeAdsManager adsManager;
    private ImageLoader imageLoader;

    /**
     * the title of the AD View 广告标题
     */
    private TextView titleView;
    private TextView smallTitleView;
    /**
     * the icon of the AD View 广告的icon
     */
    private ImageView iconView;
    private ImageView smallIconView;
    /**
     * the star rating of the AD View 广告星级
     */
    private RatingBar ratingView;
    private RatingBar smallRatingView;
    /**
     * ad describe 广告介绍
     */
    private TextView descView;
    private TextView smallDescView;
    /**
     * ad big image 广告大图
     */
    private ImageView bigImgView;
    /**
     * ad button 广告按钮
     */
    private TextView btnView;
    private TextView smallBtnView;
    /**
     * the loading view 加载视图
     */
    private ProgressBar loadView;
    /**
     * big image ad view 大图广告
     */
    private RelativeLayout bigADLayout;
    /**
     * small image ad view 小图广告
     */
    private RelativeLayout smallADLayout;
    /**
     * load background view 加载背景视图
     */
    private View bgView;

    private NativeAd mNativeAD;

    private int mPositon = 0;

    private Handler mHandler = new Handler();


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ad_card);
        initView();
        initData();
    }

    /**
     * initialize the view method 初始化视图
     */
    private void initView() {
        bigADLayout = (RelativeLayout) findViewById(R.id.big_ad);
        smallADLayout = (RelativeLayout) findViewById(R.id.small_ad);
        // big image ad
        titleView = (TextView) findViewById(R.id.card_name);
        iconView = (ImageView) findViewById(R.id.card_icon);
        ratingView = (RatingBar) findViewById(R.id.card_rating);
        descView = (TextView) findViewById(R.id.card__des);
        bigImgView = (ImageView) findViewById(R.id.card_image);
        btnView = (TextView) findViewById(R.id.card_btn);
        // small image ad
        smallTitleView = (TextView) findViewById(R.id.small_card_name);
        smallIconView = (ImageView) findViewById(R.id.small_card_icon);
        smallRatingView = (RatingBar) findViewById(R.id.small_card_rating);
        smallDescView = (TextView) findViewById(R.id.small_card__des);
        smallBtnView = (TextView) findViewById(R.id.small_card_btn);

        loadView = (ProgressBar) findViewById(R.id.load_view);
        bgView = findViewById(R.id.white_bg);
    }

    /**
     * initialize the data method 初始化数据
     */
    private void initData() {
        imageLoader = ImageLoaderHelper.getInstance(getApplicationContext());
        adsManager = new DuNativeAdsManager(getApplicationContext(), PID, CACHESZIE);
    }

    @Override
    protected void onResume() {
        super.onResume();
        if (adsManager != null) {
            adsManager.setListener(listener);
            adsManager.load();
        }
    }

    private LinkedList<NativeAd> lists = new LinkedList<NativeAd>();
    AdListArrivalListener listener = new AdListArrivalListener() {
        NativeAd nativeAD;
        //返回广告list
        @Override
        public void onAdLoaded(List arg0) {
            if (!lists.isEmpty()) {
                lists.clear();
            }
            for (int i = 0; i < arg0.size(); i++) {
                //获取单个广告对象
                nativeAD = (NativeAd) arg0.get(i);
                if (!(nativeAD.equals(null))) {
                    lists.add(nativeAD);
                }
            }
            if (lists.size() == CACHESZIE) {
                mHandler.removeCallbacksAndMessages(null);
                mHandler.post(mRunnable);
            }
        }

        //返回广告错误码
        @Override
        public void onAdError(AdError arg0) {
            Log.d(TAG, "onError : " + arg0.getErrorCode());

        }

    };


    private Runnable mRunnable = new Runnable() {
        @Override
        public void run() {
            if (mPositon < lists.size()) {
                mNativeAD = lists.get(mPositon);
                mNativeAD.setMobulaAdListener(callback);
                String url = mNativeAD.getAdCoverImageUrl();
                if (TextUtils.isEmpty(url)) {
                    showSmallAdView(mNativeAD);
                } else {
                    showBigAdView(mNativeAD);
                }
                mPositon++;

            } else {
                mPositon = 0;
            }
            mHandler.postDelayed(mRunnable, 3000);
        }
    };

    DuAdDataCallBack callback = new DuAdDataCallBack() {

        @Override
        public void onAdLoaded(NativeAd data) {
        }

        @Override
        public void onAdError(AdError error) {
        }

        @Override
        public void onAdClick() {
            Log.d(TAG, "onClick : click list ad");
        }
    };

    /**
     * show small ad 显示小图广告
     * @param ad
     */
    private void showSmallAdView(NativeAd ad) {
        smallTitleView.setText(ad.getAdTitle());
        smallRatingView.setRating(ad.getAdStarRating());
        imageLoader.displayImage(ad.getAdIconUrl(), smallIconView);
        smallDescView.setText(ad.getAdBody());
        smallBtnView.setText(ad.getAdCallToAction());
        mNativeAD.registerViewForInteraction(smallBtnView);

        bigADLayout.setVisibility(View.GONE);
        smallADLayout.setVisibility(View.VISIBLE);
        loadView.setVisibility(View.GONE);
        bgView.setVisibility(View.GONE);
    }

    /**
     * show big ad 显示da图广告
     * @param ad
     */
    private void showBigAdView(NativeAd ad) {
        smallADLayout.setVisibility(View.GONE);
        bigADLayout.setVisibility(View.VISIBLE);

        titleView.setText(ad.getAdTitle());
        ratingView.setRating(ad.getAdStarRating());
        imageLoader.displayImage(ad.getAdIconUrl(), iconView);
        descView.setText("");
        btnView.setText(ad.getAdCallToAction());
        bgView.setVisibility(View.GONE);
        mNativeAD.registerViewForInteraction(btnView);
        imageLoader.displayImage(ad.getAdCoverImageUrl(), bigImgView, new ImageLoadingListener() {

            @Override
            public void onLoadingStarted(String paramString, View paramView) {
            }

            @Override
            public void onLoadingFailed(String paramString, View paramView, FailReason paramFailReason) {
            }

            @Override
            public void onLoadingComplete(String paramString, View paramView, Bitmap paramBitmap) {
                loadView.setVisibility(View.GONE);

            }

            @Override
            public void onLoadingCancelled(String paramString, View paramView) {
            }
        });
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        adsManager.setListener(null);
        adsManager.destroy();
    }
}