
package com.mobula.sample;

import android.app.Activity;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.RatingBar;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.duapps.ad.AdError;
import com.duapps.ad.DuAdListener;
import com.duapps.ad.DuNativeAd;
import com.mobula.sample.util.ImageLoaderHelper;
import com.nostra13.universalimageloader.core.ImageLoader;
import com.nostra13.universalimageloader.core.assist.FailReason;
import com.nostra13.universalimageloader.core.listener.ImageLoadingListener;

/**
 * display the ads page 显示广告页
 * 
 * @author mobula team
 */
public class ShowAdActivity extends Activity {

    private static final String TAG = "ShowAdActivity";
    /**
     * ad recommend id 广告推荐位
     */
    private static final int PID = 10032;
    /**
     * cache data size 缓存大小
     */
    private static final int CACHESZIE = 2;
    /**
     * mobula ad data mobula广告数据类
     */
    private DuNativeAd nativeAd;
    private ImageLoader imageLoader;

    /**
     * the title of the AD View 广告标题
     */
    private TextView titleView;
    private TextView smallTitleView;
    /**
     * the icon of the AD View 广告的icon
     */
    private ImageView iconView;
    private ImageView smallIconView;
    /**
     * the star rating of the AD View 广告星级
     */
    private RatingBar ratingView;
    private RatingBar smallRatingView;
    /**
     * ad describe 广告介绍
     */
    private TextView descView;
    private TextView smallDescView;
    /**
     * ad big image 广告大图
     */
    private ImageView bigImgView;
    /**
     * ad button 广告按钮
     */
    private TextView btnView;
    private TextView smallBtnView;
    /**
     * the loading view 加载视图
     */
    private ProgressBar loadView;
    /**
     * big image ad view 大图广告
     */
    private RelativeLayout bigADLayout;
    /**
     * small image ad view 小图广告
     */
    private RelativeLayout smallADLayout;
    /**
     * load background view 加载背景视图
     */
    private View bgView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ad_card);
        initView();
        initData();
    }

    /**
     * initialize the view method 初始化视图
     */
    private void initView() {
        bigADLayout = (RelativeLayout) findViewById(R.id.big_ad);
        smallADLayout = (RelativeLayout) findViewById(R.id.small_ad);
        // big image ad
        titleView = (TextView) findViewById(R.id.card_name);
        iconView = (ImageView) findViewById(R.id.card_icon);
        ratingView = (RatingBar) findViewById(R.id.card_rating);
        descView = (TextView) findViewById(R.id.card__des);
        bigImgView = (ImageView) findViewById(R.id.card_image);
        btnView = (TextView) findViewById(R.id.card_btn);
        // small image ad
        smallTitleView = (TextView) findViewById(R.id.small_card_name);
        smallIconView = (ImageView) findViewById(R.id.small_card_icon);
        smallRatingView = (RatingBar) findViewById(R.id.small_card_rating);
        smallDescView = (TextView) findViewById(R.id.small_card__des);
        smallBtnView = (TextView) findViewById(R.id.small_card_btn);

        loadView = (ProgressBar) findViewById(R.id.load_view);
        bgView = findViewById(R.id.white_bg);
    }

    /**
     * initialize the data method 初始化数据
     */
    private void initData() {
        imageLoader = ImageLoaderHelper.getInstance(getApplicationContext());
        nativeAd = new DuNativeAd(this, PID, CACHESZIE);
    }

    @Override
    protected void onResume() {
        super.onResume();
        if (nativeAd != null) {
            nativeAd.setMobulaAdListener(mListener);
            nativeAd.load();
        }
    }

    DuAdListener mListener = new DuAdListener() {

        @Override
        public void onError(DuNativeAd ad, AdError error) {
            Log.d(TAG, "onError : " + error.getErrorCode());
        }

        @Override
        public void onClick(DuNativeAd ad) {
            Log.d(TAG, "onClick : click ad");
        }

        @Override
        public void onAdLoaded(final DuNativeAd ad) {
            Log.d(TAG, "onAdLoaded : " + ad.getTitle());

            runOnUiThread(new Runnable() {

                @Override
                public void run() {

                    String url = ad.getImageUrl();
                    if (TextUtils.isEmpty(url)) {
                        showSmallAdView(ad);
                    } else {
                        showBigAdView(ad);
                    }

                }
            });
        }
    };


    /**
     * show small ad 显示小图广告
     * 
     * @param ad
     */
    private void showSmallAdView(DuNativeAd ad) {
        smallTitleView.setText(ad.getTitle());
        smallRatingView.setRating(ad.getRatings());
        imageLoader.displayImage(ad.getIconUrl(), smallIconView);
        smallDescView.setText(ad.getShortDesc());
        smallBtnView.setText(ad.getCallToAction());
        nativeAd.registerViewForInteraction(smallBtnView);

        bigADLayout.setVisibility(View.GONE);
        smallADLayout.setVisibility(View.VISIBLE);
        loadView.setVisibility(View.GONE);
        bgView.setVisibility(View.GONE);
    }

    /**
     * show big ad 显示大图广告
     * 
     * @param ad
     */
    private void showBigAdView(DuNativeAd ad) {
        smallADLayout.setVisibility(View.GONE);
        bigADLayout.setVisibility(View.VISIBLE);

        titleView.setText(ad.getTitle());
        ratingView.setRating(ad.getRatings());
        imageLoader.displayImage(ad.getIconUrl(), iconView);
        descView.setText("");
        btnView.setText(ad.getCallToAction());
        bgView.setVisibility(View.GONE);
        nativeAd.registerViewForInteraction(btnView);
        imageLoader.displayImage(ad.getImageUrl(), bigImgView,
                new ImageLoadingListener() {

                    @Override
                    public void onLoadingStarted(String paramString, View paramView) {
                    }

                    @Override
                    public void onLoadingFailed(String paramString, View paramView,
                            FailReason paramFailReason) {
                    }

                    @Override
                    public void onLoadingComplete(String paramString,
                            View paramView, Bitmap paramBitmap) {
                        loadView.setVisibility(View.GONE);
                       
                    }

                    @Override
                    public void onLoadingCancelled(String paramString,
                            View paramView) {
                    }
                });
    }

}
